==> camel-k-model-v1-6.6.2-sources.jar: io/fabric8/camelk/v1/SpectrumTaskFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SpectrumTaskFluentImpl<A extends SpectrumTaskFluent<A>> extends BaseFluent<A> implements SpectrumTaskFluent<A>{
  public SpectrumTaskFluentImpl() {
  }
  public SpectrumTaskFluentImpl(SpectrumTask instance) {
    this.withBaseImage(instance.getBaseImage()); 
    this.withContextDir(instance.getContextDir()); 
    this.withImage(instance.getImage()); 
    this.withName(instance.getName()); 
    this.withRegistry(instance.getRegistry()); 
  }
  private String baseImage;
  private String contextDir;
  private String image;
  private String name;
  private RegistrySpecBuilder registry;
  public String getBaseImage() {
    return this.baseImage;
  }
  public A withBaseImage(String baseImage) {
    this.baseImage=baseImage; return (A) this;
  }
  public Boolean hasBaseImage() {
    return this.baseImage != null;
  }
  public String getContextDir() {
    return this.contextDir;
  }
  public A withContextDir(String contextDir) {
    this.contextDir=contextDir; return (A) this;
  }
  public Boolean hasContextDir() {
    return this.contextDir != null;
  }
  public String getImage() {
    return this.image;
  }
  public A withImage(String image) {
    this.image=image; return (A) this;
  }
  public Boolean hasImage() {
    return this.image != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildRegistry instead.
   * @return The buildable object.
   */
  @Deprecated
  public RegistrySpec getRegistry() {
    return this.registry!=null ?this.registry.build():null;
  }
  public RegistrySpec buildRegistry() {
    return this.registry!=null ?this.registry.build():null;
  }
  public A withRegistry(RegistrySpec registry) {
    _visitables.get("registry").remove(this.registry);
    if (registry!=null){ this.registry= new RegistrySpecBuilder(registry); _visitables.get("registry").add(this.registry);} else { this.registry = null; _visitables.get("registry").remove(this.registry); } return (A) this;
  }
  public Boolean hasRegistry() {
    return this.registry != null;
  }
  public A withNewRegistry(String address,String ca,Boolean insecure,String organization,String secret) {
    return (A)withRegistry(new RegistrySpec(address, ca, insecure, organization, secret));
  }
  public SpectrumTaskFluent.RegistryNested<A> withNewRegistry() {
    return new SpectrumTaskFluentImpl.RegistryNestedImpl();
  }
  public SpectrumTaskFluent.RegistryNested<A> withNewRegistryLike(RegistrySpec item) {
    return new SpectrumTaskFluentImpl.RegistryNestedImpl(item);
  }
  public SpectrumTaskFluent.RegistryNested<A> editRegistry() {
    return withNewRegistryLike(getRegistry());
  }
  public SpectrumTaskFluent.RegistryNested<A> editOrNewRegistry() {
    return withNewRegistryLike(getRegistry() != null ? getRegistry(): new RegistrySpecBuilder().build());
  }
  public SpectrumTaskFluent.RegistryNested<A> editOrNewRegistryLike(RegistrySpec item) {
    return withNewRegistryLike(getRegistry() != null ? getRegistry(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SpectrumTaskFluentImpl that = (SpectrumTaskFluentImpl) o;
    if (baseImage != null ? !baseImage.equals(that.baseImage) :that.baseImage != null) return false;
    if (contextDir != null ? !contextDir.equals(that.contextDir) :that.contextDir != null) return false;
    if (image != null ? !image.equals(that.image) :that.image != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (registry != null ? !registry.equals(that.registry) :that.registry != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(baseImage,  contextDir,  image,  name,  registry,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (baseImage != null) { sb.append("baseImage:"); sb.append(baseImage + ","); }
    if (contextDir != null) { sb.append("contextDir:"); sb.append(contextDir + ","); }
    if (image != null) { sb.append("image:"); sb.append(image + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (registry != null) { sb.append("registry:"); sb.append(registry); }
    sb.append("}");
    return sb.toString();
  }
  class RegistryNestedImpl<N> extends RegistrySpecFluentImpl<SpectrumTaskFluent.RegistryNested<N>> implements SpectrumTaskFluent.RegistryNested<N>,Nested<N>{
    RegistryNestedImpl(RegistrySpec item) {
      this.builder = new RegistrySpecBuilder(this, item);
    }
    RegistryNestedImpl() {
      this.builder = new RegistrySpecBuilder(this);
    }
    RegistrySpecBuilder builder;
    public N and() {
      return (N) SpectrumTaskFluentImpl.this.withRegistry(builder.build());
    }
    public N endRegistry() {
      return and();
    }
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/SpectrumTaskFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SpectrumTaskFluentImpl<A extends SpectrumTaskFluent<A>> extends BaseFluent<A> implements SpectrumTaskFluent<A>{
  public SpectrumTaskFluentImpl() {
  }
  public SpectrumTaskFluentImpl(SpectrumTask instance) {
    if (instance != null) {
      this.withBaseImage(instance.getBaseImage());
      this.withContextDir(instance.getContextDir());
      this.withImage(instance.getImage());
      this.withName(instance.getName());
      this.withRegistry(instance.getRegistry());
    }
  }
  private String baseImage;
  private String contextDir;
  private String image;
  private String name;
  private RegistrySpecBuilder registry;
  public String getBaseImage() {
    return this.baseImage;
  }
  public A withBaseImage(String baseImage) {
    this.baseImage=baseImage; return (A) this;
  }
  public Boolean hasBaseImage() {
    return this.baseImage != null;
  }
  public String getContextDir() {
    return this.contextDir;
  }
  public A withContextDir(String contextDir) {
    this.contextDir=contextDir; return (A) this;
  }
  public Boolean hasContextDir() {
    return this.contextDir != null;
  }
  public String getImage() {
    return this.image;
  }
  public A withImage(String image) {
    this.image=image; return (A) this;
  }
  public Boolean hasImage() {
    return this.image != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * This method has been deprecated, please use method buildRegistry instead.
   * @return The buildable object.
   */
  @Deprecated
  public RegistrySpec getRegistry() {
    return this.registry!=null ?this.registry.build():null;
  }
  public RegistrySpec buildRegistry() {
    return this.registry!=null ?this.registry.build():null;
  }
  public A withRegistry(RegistrySpec registry) {
    _visitables.get("registry").remove(this.registry);
    if (registry!=null){ this.registry= new RegistrySpecBuilder(registry); _visitables.get("registry").add(this.registry);} else { this.registry = null; _visitables.get("registry").remove(this.registry); } return (A) this;
  }
  public Boolean hasRegistry() {
    return this.registry != null;
  }
  public A withNewRegistry(String address,String ca,Boolean insecure,String organization,String secret) {
    return (A)withRegistry(new RegistrySpec(address, ca, insecure, organization, secret));
  }
  public SpectrumTaskFluentImpl.RegistryNested<A> withNewRegistry() {
    return new SpectrumTaskFluentImpl.RegistryNestedImpl();
  }
  public SpectrumTaskFluentImpl.RegistryNested<A> withNewRegistryLike(RegistrySpec item) {
    return new SpectrumTaskFluentImpl.RegistryNestedImpl(item);
  }
  public SpectrumTaskFluentImpl.RegistryNested<A> editRegistry() {
    return withNewRegistryLike(getRegistry());
  }
  public SpectrumTaskFluentImpl.RegistryNested<A> editOrNewRegistry() {
    return withNewRegistryLike(getRegistry() != null ? getRegistry(): new RegistrySpecBuilder().build());
  }
  public SpectrumTaskFluentImpl.RegistryNested<A> editOrNewRegistryLike(RegistrySpec item) {
    return withNewRegistryLike(getRegistry() != null ? getRegistry(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SpectrumTaskFluentImpl that = (SpectrumTaskFluentImpl) o;
    if (!java.util.Objects.equals(baseImage, that.baseImage)) return false;

    if (!java.util.Objects.equals(contextDir, that.contextDir)) return false;

    if (!java.util.Objects.equals(image, that.image)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(registry, that.registry)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(baseImage,  contextDir,  image,  name,  registry,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (baseImage != null) { sb.append("baseImage:"); sb.append(baseImage + ","); }
    if (contextDir != null) { sb.append("contextDir:"); sb.append(contextDir + ","); }
    if (image != null) { sb.append("image:"); sb.append(image + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (registry != null) { sb.append("registry:"); sb.append(registry); }
    sb.append("}");
    return sb.toString();
  }
  class RegistryNestedImpl<N> extends RegistrySpecFluentImpl<SpectrumTaskFluentImpl.RegistryNested<N>> implements SpectrumTaskFluentImpl.RegistryNested<N>,Nested<N>{
    RegistryNestedImpl(RegistrySpec item) {
      this.builder = new RegistrySpecBuilder(this, item);
    }
    RegistryNestedImpl() {
      this.builder = new RegistrySpecBuilder(this);
    }
    RegistrySpecBuilder builder;
    public N and() {
      return (N) SpectrumTaskFluentImpl.this.withRegistry(builder.build());
    }
    public N endRegistry() {
      return and();
    }
    
  }
  
}
